@@ -1,8 +1,9 @@
-subset_bevimed_m <- function(G, min_ac=1L, variant_weights=NULL, ...) {
-	vars <- subset_variants(G=G, min_ac=min_ac, return_variants=TRUE)
+subset_bevimed_m <- function(G, G2=NULL, min_ac=1L, variant_weights=NULL, ...) {
+	vars <- subset_variants(G=if (is.null(G2)) G else G + G2, min_ac=min_ac, return_variants=TRUE)
 
 	bevimed_m(
 		G=G[,vars,drop=FALSE],
+		G2=if (is.null(G2)) NULL else G2[,vars,drop=FALSE],
 		min_ac=min_ac,
 		variant_weights=if (is.null(variant_weights)) NULL else variant_weights[vars],
 		...
@@ -10,12 +11,11 @@ subset_bevimed_m <- function(G, min_ac=1L, variant_weights=NULL, ...) {
 }
 
 #' @title Bayesian Evaluation of Variant Involvement in Mendelian Disease 
-#'
 #' @description Infer probabilities of association between disease label and locus and posterior parameter values under BeviMed model.
-#' 
 #' @template y
 #' @template G_matrix
 #' @template ploidy
+#' @template G2
 #' @template prior_prob_association
 #' @template prior_prob_dominant
 #' @param dominant_args Arguments to pass to \code{\link{bevimed_m}} conditioning on dominant inheritance.
@@ -29,6 +29,7 @@ bevimed <- function(
 	y,
 	G,
 	ploidy=rep(2L, length(y)),
+	G2=NULL,
 	prior_prob_association=0.01,
 	prior_prob_dominant=0.5,
 	dominant_args=NULL,	
@@ -46,6 +47,7 @@ bevimed <- function(
 		y=y,
 		G=G,
 		ploidy=ploidy,
+		G2=G2,
 		prior_prob_association=priors,
 		variant_sets=list(dominant=seq(length.out=ncol(G)), recessive=seq(length.out=ncol(G))),
 		moi=c("dominant","recessive"),
@@ -70,7 +72,6 @@ gamma0_evidence <- function(
 }
 
 #' @title Extract evidence for model gamma = 1
-#' 
 #' @description Extract evidence from \code{BeviMed_m} object.
 #' @template x_BeviMed_m
 #' @return Log marginal likelihood.
@@ -82,9 +83,7 @@ extract_gamma1_evidence <- function(x) {
 }
 
 #' @title Calculate evidence under model gamma = 1 
-#'
 #' @description Use \code{\link{bevimed_m}} to perform inference under model gamma = 1 and return only the log evidence/integrated likelihood.
-#' 
 #' @template dots_to_bevimed_m
 #' @return Log marginal likelihood.
 #' @export
@@ -101,9 +100,7 @@ gamma1_evidence <- function(
 }
 
 #' @title Extract expected number of explained cases
-#'
 #' @description Extract expected number of cases explained by pathogenic configurations of alleles from \code{BeviMed_m} object.
-#' 
 #' @template x_BeviMed_m
 #' @return Numeric value.
 #' @export
@@ -118,9 +115,7 @@ extract_expected_explained <- function(x) {
 }
 
 #' @title Calculate expected number of explained cases
-#'
 #' @description Use \code{\link{bevimed_m}} to perform inference under model gamma = 1 and return only the expected number of cases explained by pathogenic allele configurations.
-#'
 #' @template dots_to_bevimed_m
 #' @return Numeric value.
 #' @export
@@ -135,7 +130,6 @@ expected_explained <- function(...) {
 
 #' @title Extract expected number of pathogenic variants in cases
 #' @description Extract expected number of variants involved in cases explained by pathogenic conigurations of alleles from \code{BeviMed_m} object.
-#' 
 #' @template x_BeviMed_m
 #' @return Numeric value.
 #' @export
@@ -146,7 +140,8 @@ extract_explaining_variants <- function(x) {
 		if (("z" %in% names(x[["traces"]]))*dim(x[["traces"]][["z"]])[1] == 0)
 			stop("Must make sure to set 'return_z_trace=TRUE' and 'return_x_trace=TRUE' in call to 'bevimed_m' to use this function")
 		G <- x$parameters$G
-		logicalG <- matrix(G > 0, nrow=nrow(G), ncol=ncol(G))
+		G2 <- if (is.null(x$parameters$G2)) matrix(0, nrow=nrow(G), ncol=ncol(G)) else x$parameters$G2
+		logicalG <- matrix((G+G2) > 0, nrow=nrow(G), ncol=ncol(G))
 		y <- x$parameters$y
 		mean(mapply(
 			SIMPLIFY=TRUE,
@@ -158,9 +153,7 @@ extract_explaining_variants <- function(x) {
 }
 
 #' @title Calculate expected number of pathogenic variants in cases
-#'
 #' @description Use \code{\link{bevimed_m}} to perform inference under model gamma = 1 and return only the expected number of pathogenic variants in cases.
-#'
 #' @template dots_to_bevimed_m
 #' @return Numeric value.
 #' @export
@@ -169,10 +162,8 @@ explaining_variants <- function(...) {
 	extract_explaining_variants(subset_bevimed_m(return_z_trace=TRUE, return_x_trace=TRUE, ...))
 }
 
-#' Calculate log Bayes factor between an association model with a given mode of inheritance and model gamma = 0
-#' 
+#' @title Calculate log Bayes factor between an association model with a given mode of inheritance and model gamma = 0
 #' @description Compute log Bayes factor of an association model and model gamma = 0. 
-#'
 #' @template y
 #' @template dots_to_bevimed_m
 #' @template tau0_shape
@@ -192,9 +183,7 @@ log_BF <- function(
 }
 
 #' @title Calculate probability of association for one mode of inheritance
-#'
 #' @description Equivalent to \code{\link{prob_association}} where the prior probability of one mode of inheritance is 1. This function is faster, as it only calls \code{\link{bevimed_m}} once.
-#'
 #' @template y
 #' @template min_ac
 #' @template prior_prob_association
@@ -214,7 +203,6 @@ prob_association_m <- function(
 }
 
 #' @title Extract the posterior probability of association
-#'
 #' @description Get posterior probability of association as numeric value, or optionally as numeric vector of length two with probabilities broken down by mode of inheritance (by passing \code{by_model=TRUE}), from a \code{BeviMed} object.
 #' @template x_BeviMed
 #' @template by_model
@@ -238,7 +226,6 @@ extract_prob_association <- function(x, by_model=FALSE) {
 }
 
 #' @title Calculate probability of association
-#'
 #' @description Calculate probability of an association between case/control label and allele configuration, optionally broken down by mode of inheritance/model.
 #' @template by_model
 #' @param ... Arguments to pass to \code{\link{bevimed}}. 
@@ -268,9 +255,7 @@ variant_marginals <- function(var_probs_by_model, variant_sets, k) {
 }
 
 #' @title Extract variant marginal probabilities of pathogenicity
-#'
 #' @description Extract the marginal probability of pathogenicity for individual variants from \code{BeviMed} object, optionally broken down by mode of inheritance/model.
-#'
 #' @template x_BeviMed
 #' @template by_model
 #' @return A vector of probabilities of pathogenicity for individual variants, or if \code{by_model} is \code{TRUE}, then a matrix of probabilities, with rows corresponding to modes of inheritance and columns to variants.
@@ -287,10 +272,8 @@ extract_prob_pathogenic <- function(x, by_model=TRUE) {
 	}
 }
 
-#' Calculate variant marginal probabilities of pathogencity 
-#'
-#' Calls \code{\link{bevimed}} and \code{\link{extract_prob_pathogenic}} to obtain marginal probabilities of pathogenicity.
-#'
+#' @title Calculate variant marginal probabilities of pathogencity 
+#' @description Calls \code{\link{bevimed}} and \code{\link{extract_prob_pathogenic}} to obtain marginal probabilities of pathogenicity.
 #' @template by_model
 #' @param ... Arguments to pass to \code{\link{bevimed}}. 
 #' @return If \code{by_model} is \code{FALSE}, a vector of probabilities of pathogenicity for each variant, otherwise a list of vectors of probabilities of pathogenicity conditional on each compared association model.
@@ -310,9 +293,7 @@ t1_z_trace <- function(x) {
 }
 
 #' @title Extract probability of pathogenicity for variant conditional on a given association model
-#'
 #' @description Extract the probability of pathogenicity for individual variants from a \code{BeviMed_m} object.
-#'
 #' @template x_BeviMed_m
 #' @return Vector of probabilities of pathogenicity for individual variants.
 #' @export
@@ -324,9 +305,8 @@ extract_conditional_prob_pathogenic <- function(x) {
 	}
 }
 
-#' Calculate probability of pathogencity for variants conditional on mode of inheritance.
-#'
-#' Calls \code{\link{bevimed_m}} and \code{\link{extract_conditional_prob_pathogenic}} to obtain probabilities of pathogenicity.
+#' @title Calculate probability of pathogencity for variants conditional on mode of inheritance.
+#' @description Calls \code{\link{bevimed_m}} and \code{\link{extract_conditional_prob_pathogenic}} to obtain probabilities of pathogenicity.
 #' @template dots_to_bevimed_m
 #' @return Probabilities of pathogenicity.
 #' @export
@@ -347,6 +327,7 @@ conditional_prob_pathogenic <- function(
 #' @template y
 #' @template G_matrix
 #' @template ploidy
+#' @template G2
 #' @param variant_sets List of integer vectors corresponding to sets of indices of \code{G}, each of which is to be considered in a model explaining the phenotype, \code{y}.
 #' @template prior_prob_association
 #' @template tau0_shape
@@ -360,6 +341,7 @@ bevimed_polytomous <- function(
 	y,
 	G,
 	ploidy=rep(2L, length(y)),
+	G2=NULL,
 	variant_sets, 
 	prior_prob_association=rep(0.01/length(variant_sets), length(variant_sets)),
 	tau0_shape=c(1, 1),
@@ -392,12 +374,13 @@ bevimed_polytomous <- function(
 				ploidy=ploidy,
 				y=y,
 				G=G,
-				variant_table=to_var_tab(get_G_args(G)),
+				G2=G2,
+				variant_table=to_var_tab(if (is.null(G2)) get_G_args(G) else get_G_args(G+G2)),
 				variant_sets=variant_sets,
 				moi=moi
 			),
 			models=Map(
-				f=function(var_inds, min_ac, args) { do.call(what=bevimed_m, c(list(y=y, G=G[,var_inds,drop=FALSE], min_ac=min_ac), args, shared)) },
+				f=function(var_inds, min_ac, args) { do.call(what=bevimed_m, c(list(y=y, G=G[,var_inds,drop=FALSE], G2=if (is.null(G2)) NULL else G2[,var_inds,drop=FALSE], min_ac=min_ac), args, shared)) },
 				variant_sets,
 				lapply(moi, function(m) if (m=="dominant") { 1L } else { if (length(ploidy) == 0) 2L else ploidy }),
 				model_specific_args
