@@ -6,6 +6,8 @@
 #' @param block_ends Integer vector of (exclusive) k 0-indexed end positions.
 #' @param cases 0 based vector of case indices with respect to y.
 #' @param counts Vector of variant counts.
+#' @param counts2 Vector of variant counts on second haplotype.
+#' @template phased
 #' @template min_ac
 #' @param tau_shape Beta distribution parameterisation of benign variant configuration rate of affection, q.
 #' @param pi_shape Beta distribution parameterisation of pathogenic variant configuration rate of affection, p.
@@ -42,6 +44,8 @@ call_cpp <- function(
 	block_ends,
 	cases,
 	counts,
+	counts2,
+	phased,
 	min_ac,
 	tau_shape,
 	pi_shape,
@@ -95,6 +99,8 @@ call_cpp <- function(
 		block_ends,
 		cases,
 		counts,
+		counts2,
+		phased,
 		if (length(min_ac) == length(y)) min_ac else rep(min_ac, length(y)),
 		tau_shape[1],
 		tau_shape[2],
@@ -380,15 +386,18 @@ get_G_args <- function(G) {
 		list(
 			cases=cases[counts > 0],
 			counts=counts[counts > 0],
+			counts2=rep(0L, sum(counts > 0)),
 			block_ends=as.integer(block_ends),
 			block_starts=as.integer(block_starts)
 		)
 	} else if (is(G, "sparseMatrix")) {
 		p <- slot(G, "p")
 		G_i <- slot(G, "i")
+		counts <- as.integer(slot(G, "x"))
 		return(list(
 			cases=rep(1L, length(G_i))+G_i,
-			counts=as.integer(slot(G, "x")),
+			counts=counts,
+			counts2=rep(0L, length(counts)),
 			block_ends=p[-1L],
 			block_starts=p[-length(p)]
 		))
@@ -397,20 +406,29 @@ get_G_args <- function(G) {
 	}
 }
 
+get_phasedG_args <- function(G1, G2) {
+	if (!identical(dim(G1), dim(G2))) { stop("genotype matrices for both haplotypes must have same dimensions!") }
+	o <- get_G_args(G1 + G2)
+	o2 <- get_G_args(G1 * 2 + G2)
+	o$counts <- o2$counts - o$counts
+	o$counts2 <- o2$counts - 2 * o$counts
+	o
+}
+
 to_var_tab <- function(G_args) {
 	data.frame(
 		variant=unlist(mapply(SIMPLIFY=FALSE, FUN=rep, seq(length.out=length(G_args$block_starts)), G_args$block_ends-G_args$block_starts)),
 		case=G_args$cases,
-		count=G_args$counts
+		count=G_args$counts + G_args$counts2
 	)
 }
 
 #' @title Perform inference under model gamma = 1 conditional on mode of inheritance
-#'
 #' @description Sample from posterior distribution of parameters under model gamma = 1 and conditional on mode of inheritance, set via the \code{min_ac} argument.
 #' @template y
 #' @template G_matrix
 #' @template min_ac
+#' @template G2
 #' @template tau_shape
 #' @template pi_shape
 #' @template omega_shape 
@@ -452,6 +470,7 @@ bevimed_m <- function(
 	y,
 	G,
 	min_ac=1L,
+	G2=NULL,
 	tau_shape=c(1, 1),
 	pi_shape=c(6, 1),
 	omega_shape=if (max(min_ac) == 1L) c(2, 8) else c(2, 2),
@@ -500,9 +519,9 @@ bevimed_m <- function(
 			}
 		}
 		
-	G_args <- get_G_args(G)
+	G_args <- if (is.null(G2)) get_G_args(G) else get_phasedG_args(G, G2)
 
-	G_logical <- G > 0
+	G_logical <- if (is.null(G2)) { G > 0 } else { (G + G2) > 0 }
 	comphet_cases <- which(rowSums(G_logical) > 1L)
 	comphet_variants <- vector(mode="list", length=length(comphet_cases))
 	for (chci in seq_along(comphet_cases)) {
@@ -522,6 +541,8 @@ bevimed_m <- function(
 		block_ends=G_args$block_ends,
 		cases=G_args$cases-1L,
 		counts=G_args$counts,
+		counts2=G_args$counts2,
+		phased=!is.null(G2),
 		min_ac=min_ac,
 		tau_shape=tau_shape,
 		pi_shape=pi_shape,
@@ -687,6 +708,7 @@ bevimed_m <- function(
 					variant_table=to_var_tab(G_args),
 					c_weights=c_weights,
 					G=G,
+					G2=G2,
 					N=length(y),
 					k=ncol(G)
 				))
