@@ -8,6 +8,8 @@ List bevimed_mc(
 	IntegerVector var_block_stop_index,
 	IntegerVector cases,
 	IntegerVector counts,
+	IntegerVector hap2,
+	bool haplo_mode,
 	IntegerVector min_ac,
 	double tau_shape1,
 	double tau_shape2,
@@ -84,13 +86,16 @@ List bevimed_mc(
 	}
 
 	IntegerMatrix pathogenic_var_count(num_temps, n);
+	IntegerMatrix pvc2(num_temps, n);
 	IntegerVector temporary_pathogenic_var_count(n, 0);
+	IntegerVector temporary_pvc2(n, 0);
 	LogicalVector temporary_counted_indicator(n, false);
 
 	LogicalMatrix x(num_temps, n);
 	for (int temp = 0; temp < num_temps; temp++) {
 		for (int i = 0; i < n; i++) {
 			pathogenic_var_count(temp, i) = 0;
+			pvc2(temp, i) = 0;
 			x(temp, i) = false;
 		}
 	}
@@ -103,11 +108,12 @@ List bevimed_mc(
 		for (int v = 0; v < k; v++) {
 			for (int case_with_v = var_block_start_index[v]; case_with_v < var_block_stop_index[v]; case_with_v++) {
 				pathogenic_var_count(temp, cases[case_with_v]) += (int)z(temp, v) * counts[case_with_v];
+				pvc2(temp, cases[case_with_v]) += (int)z(temp, v) * hap2[case_with_v];
 			}
 		}
 
 		for (int i = 0; i < n; i++) {
-			x(temp, i) = pathogenic_var_count(temp, i) >= min_ac[i];
+			x(temp, i) = haplo_mode ? (((pathogenic_var_count(temp, i) > 0) + (pvc2(temp, i) > 0)) >= min_ac[i]) : (pathogenic_var_count(temp, i) >= min_ac[i]);
 			count_x1[temp] += (int)x(temp, i);
 			if (y[i]) { 
 				count_y1x1[temp] += (int)x(temp, i);
@@ -181,12 +187,24 @@ List bevimed_mc(
 				int c_s11 = count_y1x1[chain_number];
 				int c_s10 = count_x1[chain_number] - count_y1x1[chain_number];
 
-				for (int i = var_block_start_index[v]; i < var_block_stop_index[v]; i++) {
-					int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v) ? (-counts[i]) : counts[i]);
-					bool alt_x = alt_pathogenic_var_count >= min_ac[cases[i]];
-					if (alt_x != x(chain_number, cases[i])) {
-						dx1 += (int)alt_x - (int)x(chain_number, cases[i]);
-						if (y[cases[i]]) dy1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+				if (haplo_mode) {
+					for (int i = var_block_start_index[v]; i < var_block_stop_index[v]; i++) {
+						int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v) ? (-counts[i]) : counts[i]);
+						int alt_pvc2 = pvc2(chain_number, cases[i]) + (z(chain_number, v) ? (-hap2[i]) : hap2[i]);
+						bool alt_x = ((alt_pathogenic_var_count > 0) + (alt_pvc2 > 0)) >= min_ac[cases[i]];
+						if (alt_x != x(chain_number, cases[i])) {
+							dx1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							if (y[cases[i]]) dy1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+						}
+					}
+				} else {
+					for (int i = var_block_start_index[v]; i < var_block_stop_index[v]; i++) {
+						int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v) ? (-counts[i]) : counts[i]);
+						bool alt_x = alt_pathogenic_var_count >= min_ac[cases[i]];
+						if (alt_x != x(chain_number, cases[i])) {
+							dx1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							if (y[cases[i]]) dy1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+						}
 					}
 				}
 
@@ -223,9 +241,17 @@ List bevimed_mc(
 				if (unif_rand() < (1.0-1.0/(1.0+exp(-current_zv_log_odds)))) {
 					count_x1[chain_number] += dx1;
 					count_y1x1[chain_number] += dy1x1;
-					for (int i = var_block_start_index[v]; i < var_block_stop_index[v]; i++) {
-						pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v) ? (-counts[i]) : counts[i]);
-						x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+					if (!haplo_mode) {
+						for (int i = var_block_start_index[v]; i < var_block_stop_index[v]; i++) {
+							pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v) ? (-counts[i]) : counts[i]);
+							x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+						}
+					} else {
+						for (int i = var_block_start_index[v]; i < var_block_stop_index[v]; i++) {
+							pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v) ? (-counts[i]) : counts[i]);
+							pvc2(chain_number, cases[i]) += (z(chain_number, v) ? (-hap2[i]) : hap2[i]);
+							x(chain_number, cases[i]) = ((pathogenic_var_count(chain_number, cases[i]) > 0) + (pvc2(chain_number, cases[i]) > 0)) >= min_ac[cases[i]];
+						}
 					}
 					count_z1[chain_number] += z(chain_number, v) ? (-1) : 1;
 					z(chain_number, v) = !z(chain_number, v);
@@ -257,12 +283,24 @@ List bevimed_mc(
 					int v1_change_count_x1 = count_x1[chain_number];
 					int v1_change_count_y1x1 = count_y1x1[chain_number];
 
-					for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
-						int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v1) ? (-counts[i]) : counts[i]);
-						bool alt_x = alt_pathogenic_var_count >= min_ac[cases[i]];
-						if (alt_x != x(chain_number, cases[i])) {
-							v1_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
-							if (y[cases[i]]) v1_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+					if (haplo_mode) {
+						for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+							int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v1) ? (-counts[i]) : counts[i]);
+							int alt_pvc2 = pvc2(chain_number, cases[i]) + (z(chain_number, v1) ? (-hap2[i]) : hap2[i]);
+							bool alt_x = ((alt_pathogenic_var_count > 0) + (alt_pvc2 > 0)) >= min_ac[cases[i]];
+							if (alt_x != x(chain_number, cases[i])) {
+								v1_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v1_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
+						}
+					} else {
+						for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+							int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v1) ? (-counts[i]) : counts[i]);
+							bool alt_x = alt_pathogenic_var_count >= min_ac[cases[i]];
+							if (alt_x != x(chain_number, cases[i])) {
+								v1_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v1_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
 						}
 					}
 
@@ -274,12 +312,24 @@ List bevimed_mc(
 					int v2_change_count_x1 = count_x1[chain_number];
 					int v2_change_count_y1x1 = count_y1x1[chain_number];
 
-					for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
-						int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v2) ? (-counts[i]) : counts[i]);
-						bool alt_x = alt_pathogenic_var_count >= min_ac[cases[i]];
-						if (alt_x != x(chain_number, cases[i])) {
-							v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
-							if (y[cases[i]]) v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+					if (haplo_mode) {
+						for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+							int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v2) ? (-counts[i]) : counts[i]);
+							int alt_pvc2 = pvc2(chain_number, cases[i]) + (z(chain_number, v2) ? (-hap2[i]) : hap2[i]);
+							bool alt_x = ((alt_pathogenic_var_count > 0) + (alt_pvc2 > 0)) >= min_ac[cases[i]];
+							if (alt_x != x(chain_number, cases[i])) {
+								v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
+						}
+					} else {
+						for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+							int alt_pathogenic_var_count = pathogenic_var_count(chain_number, cases[i]) + (z(chain_number, v2) ? (-counts[i]) : counts[i]);
+							bool alt_x = alt_pathogenic_var_count >= min_ac[cases[i]];
+							if (alt_x != x(chain_number, cases[i])) {
+								v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
 						}
 					}
 
@@ -291,31 +341,58 @@ List bevimed_mc(
 					int v1_and_v2_change_count_x1 = count_x1[chain_number];
 					int v1_and_v2_change_count_y1x1 = count_y1x1[chain_number];
 					
-					for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++)
-						temporary_pathogenic_var_count[cases[i]] = pathogenic_var_count(chain_number, cases[i]);
-					for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++)
-						temporary_pathogenic_var_count[cases[i]] = pathogenic_var_count(chain_number, cases[i]);
-					for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++)
-						temporary_pathogenic_var_count[cases[i]] += (z(chain_number, v1) ? (-counts[i]) : counts[i]);
-					for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++)
-						temporary_pathogenic_var_count[cases[i]] += (z(chain_number, v2) ? (-counts[i]) : counts[i]);
-
 					for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
-						bool alt_x = temporary_pathogenic_var_count[cases[i]] >= min_ac[cases[i]];
-						if ((!temporary_counted_indicator[cases[i]]) && (alt_x != x(chain_number, cases[i]))) {
-							v1_and_v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
-							if (y[cases[i]]) v1_and_v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
-						}
-						temporary_counted_indicator[cases[i]] = true;
+						temporary_pathogenic_var_count[cases[i]] = pathogenic_var_count(chain_number, cases[i]);
+						temporary_pvc2[cases[i]] = pvc2(chain_number, cases[i]);
+					}
+					for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+						temporary_pathogenic_var_count[cases[i]] = pathogenic_var_count(chain_number, cases[i]);
+						temporary_pvc2[cases[i]] = pvc2(chain_number, cases[i]);
+					}
+					for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+						temporary_pathogenic_var_count[cases[i]] += (z(chain_number, v1) ? (-counts[i]) : counts[i]);
+						temporary_pvc2[cases[i]] += (z(chain_number, v1) ? (-hap2[i]) : hap2[i]);
+					}
+					for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+						temporary_pathogenic_var_count[cases[i]] += (z(chain_number, v2) ? (-counts[i]) : counts[i]);
+						temporary_pvc2[cases[i]] += (z(chain_number, v2) ? (-hap2[i]) : hap2[i]);
 					}
 
-					for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
-						bool alt_x = temporary_pathogenic_var_count[cases[i]] >= min_ac[cases[i]];
-						if ((!temporary_counted_indicator[cases[i]]) && (alt_x != x(chain_number, cases[i]))) {
-							v1_and_v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
-							if (y[cases[i]]) v1_and_v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+					if (haplo_mode) {
+						for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+							bool alt_x = ((temporary_pathogenic_var_count[cases[i]] > 0) + (temporary_pvc2[cases[i]] > 0)) >= min_ac[cases[i]];
+							if ((!temporary_counted_indicator[cases[i]]) && (alt_x != x(chain_number, cases[i]))) {
+								v1_and_v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v1_and_v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
+							temporary_counted_indicator[cases[i]] = true;
+						}
+						for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+							bool alt_x = ((temporary_pathogenic_var_count[cases[i]] > 0) + (temporary_pvc2[cases[i]] > 0)) >= min_ac[cases[i]];
+							if ((!temporary_counted_indicator[cases[i]]) && (alt_x != x(chain_number, cases[i]))) {
+								v1_and_v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v1_and_v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
+							temporary_counted_indicator[cases[i]] = true;
+						}
+					} else {
+						for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+							bool alt_x = temporary_pathogenic_var_count[cases[i]] >= min_ac[cases[i]];
+							if ((!temporary_counted_indicator[cases[i]]) && (alt_x != x(chain_number, cases[i]))) {
+								v1_and_v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v1_and_v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
+							temporary_counted_indicator[cases[i]] = true;
+						}
+
+						for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+							bool alt_x = temporary_pathogenic_var_count[cases[i]] >= min_ac[cases[i]];
+							if ((!temporary_counted_indicator[cases[i]]) && (alt_x != x(chain_number, cases[i]))) {
+								v1_and_v2_change_count_x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+								if (y[cases[i]]) v1_and_v2_change_count_y1x1 += (int)alt_x - (int)x(chain_number, cases[i]);
+							}
+							temporary_counted_indicator[cases[i]] = true;
 						}
-						temporary_counted_indicator[cases[i]] = true;
 					}
 
 					int v1_and_v2_change_s01 = count_y1[chain_number] - v1_and_v2_change_count_y1x1;
@@ -430,51 +507,96 @@ List bevimed_mc(
 
 
 					if (random_draw >= p_no_change) {
-						if (random_draw < (p_no_change + p_v1_change)) {
-							count_x1[chain_number] = v1_change_count_x1;
-							count_y1x1[chain_number] = v1_change_count_y1x1;
-							for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
-								pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v1) ? (-counts[i]) : counts[i]);
-								x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+						if (haplo_mode) {
+							if (random_draw < (p_no_change + p_v1_change)) {
+								count_x1[chain_number] = v1_change_count_x1;
+								count_y1x1[chain_number] = v1_change_count_y1x1;
+								for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v1) ? (-counts[i]) : counts[i]);
+									pvc2(chain_number, cases[i]) += (z(chain_number, v1) ? (-hap2[i]) : hap2[i]);
+									x(chain_number, cases[i]) = ((pathogenic_var_count(chain_number, cases[i]) > 0) + (pvc2(chain_number, cases[i]) > 0)) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v1) ? (-1) : 1;
+								z(chain_number, v1) = !z(chain_number, v1);
 							}
-							count_z1[chain_number] += z(chain_number, v1) ? (-1) : 1;
-							z(chain_number, v1) = !z(chain_number, v1);
-						}
-						else if (random_draw < p_v2_threshold) {
-							count_x1[chain_number] = v2_change_count_x1;
-							count_y1x1[chain_number] = v2_change_count_y1x1;
-							for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
-								pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v2) ? (-counts[i]) : counts[i]);
-								x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+							else if (random_draw < p_v2_threshold) {
+								count_x1[chain_number] = v2_change_count_x1;
+								count_y1x1[chain_number] = v2_change_count_y1x1;
+								for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v2) ? (-counts[i]) : counts[i]);
+									pvc2(chain_number, cases[i]) += (z(chain_number, v2) ? (-hap2[i]) : hap2[i]);
+									x(chain_number, cases[i]) = ((pathogenic_var_count(chain_number, cases[i]) > 0) + (pvc2(chain_number, cases[i]) > 0)) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v2) ? (-1) : 1;
+								z(chain_number, v2) = !z(chain_number, v2);
 							}
-							count_z1[chain_number] += z(chain_number, v2) ? (-1) : 1;
-							z(chain_number, v2) = !z(chain_number, v2);
-						}
-						else {
-							count_x1[chain_number] = v1_and_v2_change_count_x1;
-							count_y1x1[chain_number] = v1_and_v2_change_count_y1x1;
-							for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
-								pathogenic_var_count(chain_number, cases[i]) = temporary_pathogenic_var_count[cases[i]];
-								x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+							else {
+								count_x1[chain_number] = v1_and_v2_change_count_x1;
+								count_y1x1[chain_number] = v1_and_v2_change_count_y1x1;
+								for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) = temporary_pathogenic_var_count[cases[i]];
+									pvc2(chain_number, cases[i]) = temporary_pvc2[cases[i]];
+									x(chain_number, cases[i]) = ((pathogenic_var_count(chain_number, cases[i]) > 0) + (pvc2(chain_number, cases[i]) > 0)) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v1) ? (-1) : 1;
+								z(chain_number, v1) = !z(chain_number, v1);
+								for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) = temporary_pathogenic_var_count[cases[i]];
+									pvc2(chain_number, cases[i]) = temporary_pvc2[cases[i]];
+									x(chain_number, cases[i]) = ((pathogenic_var_count(chain_number, cases[i]) > 0) + (pvc2(chain_number, cases[i]) > 0)) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v2) ? (-1) : 1;
+								z(chain_number, v2) = !z(chain_number, v2);
 							}
-							count_z1[chain_number] += z(chain_number, v1) ? (-1) : 1;
-							z(chain_number, v1) = !z(chain_number, v1);
-							for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
-								pathogenic_var_count(chain_number, cases[i]) = temporary_pathogenic_var_count[cases[i]];
-								x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+						} else {
+							if (random_draw < (p_no_change + p_v1_change)) {
+								count_x1[chain_number] = v1_change_count_x1;
+								count_y1x1[chain_number] = v1_change_count_y1x1;
+								for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v1) ? (-counts[i]) : counts[i]);
+									x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v1) ? (-1) : 1;
+								z(chain_number, v1) = !z(chain_number, v1);
+							}
+							else if (random_draw < p_v2_threshold) {
+								count_x1[chain_number] = v2_change_count_x1;
+								count_y1x1[chain_number] = v2_change_count_y1x1;
+								for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) += (z(chain_number, v2) ? (-counts[i]) : counts[i]);
+									x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v2) ? (-1) : 1;
+								z(chain_number, v2) = !z(chain_number, v2);
+							}
+							else {
+								count_x1[chain_number] = v1_and_v2_change_count_x1;
+								count_y1x1[chain_number] = v1_and_v2_change_count_y1x1;
+								for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) = temporary_pathogenic_var_count[cases[i]];
+									x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v1) ? (-1) : 1;
+								z(chain_number, v1) = !z(chain_number, v1);
+								for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
+									pathogenic_var_count(chain_number, cases[i]) = temporary_pathogenic_var_count[cases[i]];
+									x(chain_number, cases[i]) = pathogenic_var_count(chain_number, cases[i]) >= min_ac[cases[i]];
+								}
+								count_z1[chain_number] += z(chain_number, v2) ? (-1) : 1;
+								z(chain_number, v2) = !z(chain_number, v2);
 							}
-							count_z1[chain_number] += z(chain_number, v2) ? (-1) : 1;
-							z(chain_number, v2) = !z(chain_number, v2);
 						}
 					}
 
 					for (int i = var_block_start_index[v1]; i < var_block_stop_index[v1]; i++) {
 						temporary_counted_indicator[cases[i]] = false;
 						temporary_pathogenic_var_count[cases[i]] = 0;
+						temporary_pvc2[cases[i]] = 0;
 					}
 					for (int i = var_block_start_index[v2]; i < var_block_stop_index[v2]; i++) {
 						temporary_counted_indicator[cases[i]] = false;
 						temporary_pathogenic_var_count[cases[i]] = 0;
+						temporary_pvc2[cases[i]] = 0;
 					}
 				}
 			}
