@@ -45,6 +45,8 @@ List bevimed_mc(
 	IntegerVector var_block_stop_index,
 	IntegerVector cases,
 	IntegerVector counts,
+	IntegerVector hap2,
+	bool haplo_mode,
 	IntegerVector min_ac,
 	double tau_shape1,
 	double tau_shape2,
